@@ -23,7 +23,6 @@
 #include <config.h>
 #endif
 
-#define _GNU_SOURCE
 #include <string.h>
 #include <stdio.h>
 
@@ -207,7 +206,7 @@ static void at_call_volume_remove(struct ofono_call_volume *cv)
 	g_free(cvd);
 }
 
-static struct ofono_call_volume_driver driver = {
+static const struct ofono_call_volume_driver driver = {
 	.name = "atmodem",
 	.probe = at_call_volume_probe,
 	.remove = at_call_volume_remove,
