@@ -29,10 +29,10 @@ extern "C" {
 #include <ofono/types.h>
 
 enum ofono_radio_access_mode {
-	OFONO_RADIO_ACCESS_MODE_ANY	= 0,
-	OFONO_RADIO_ACCESS_MODE_GSM	= 1,
-	OFONO_RADIO_ACCESS_MODE_UMTS	= 2,
-	OFONO_RADIO_ACCESS_MODE_LTE	= 3,
+	OFONO_RADIO_ACCESS_MODE_ANY	= 0x0,
+	OFONO_RADIO_ACCESS_MODE_GSM	= 0x1,
+	OFONO_RADIO_ACCESS_MODE_UMTS	= 0x2,
+	OFONO_RADIO_ACCESS_MODE_LTE	= 0x4,
 };
 
 enum ofono_radio_band_gsm {
@@ -55,24 +55,35 @@ enum ofono_radio_band_umts {
 
 struct ofono_radio_settings;
 
-typedef void (*ofono_radio_settings_rat_mode_set_cb_t)(const struct ofono_error *error,
-							void *data);
-typedef void (*ofono_radio_settings_rat_mode_query_cb_t)(const struct ofono_error *error,
+typedef void (*ofono_radio_settings_rat_mode_set_cb_t)(
+						const struct ofono_error *error,
+						void *data);
+typedef void (*ofono_radio_settings_rat_mode_query_cb_t)(
+					const struct ofono_error *error,
 					enum ofono_radio_access_mode mode,
 					void *data);
 
-typedef void (*ofono_radio_settings_band_set_cb_t)(const struct ofono_error *error,
-							void *data);
-typedef void (*ofono_radio_settings_band_query_cb_t)(const struct ofono_error *error,
+typedef void (*ofono_radio_settings_band_set_cb_t)(
+						const struct ofono_error *error,
+						void *data);
+typedef void (*ofono_radio_settings_band_query_cb_t)(
+					const struct ofono_error *error,
 					enum ofono_radio_band_gsm band_gsm,
 					enum ofono_radio_band_umts band_umts,
 					void *data);
 
-typedef void (*ofono_radio_settings_fast_dormancy_set_cb_t)(const struct ofono_error *error,
-							void *data);
-typedef void (*ofono_radio_settings_fast_dormancy_query_cb_t)(const struct ofono_error *error,
-							ofono_bool_t enable,
-							void *data);
+typedef void (*ofono_radio_settings_fast_dormancy_set_cb_t)(
+						const struct ofono_error *error,
+						void *data);
+typedef void (*ofono_radio_settings_fast_dormancy_query_cb_t)(
+						const struct ofono_error *error,
+						ofono_bool_t enable,
+						void *data);
+
+typedef void (*ofono_radio_settings_available_rats_query_cb_t)(
+						const struct ofono_error *error,
+						unsigned int available_rats,
+						void *data);
 
 struct ofono_radio_settings_driver {
 	const char *name;
@@ -101,15 +112,20 @@ struct ofono_radio_settings_driver {
 				ofono_bool_t enable,
 				ofono_radio_settings_fast_dormancy_set_cb_t,
 				void *data);
+	void (*query_available_rats)(struct ofono_radio_settings *rs,
+			ofono_radio_settings_available_rats_query_cb_t cb,
+			void *data);
 };
 
-int ofono_radio_settings_driver_register(const struct ofono_radio_settings_driver *d);
-void ofono_radio_settings_driver_unregister(const struct ofono_radio_settings_driver *d);
+int ofono_radio_settings_driver_register(
+				const struct ofono_radio_settings_driver *d);
+void ofono_radio_settings_driver_unregister(
+				const struct ofono_radio_settings_driver *d);
 
-struct ofono_radio_settings *ofono_radio_settings_create(struct ofono_modem *modem,
-							unsigned int vendor,
-							const char *driver,
-							void *data);
+struct ofono_radio_settings *ofono_radio_settings_create(
+						struct ofono_modem *modem,
+						unsigned int vendor,
+						const char *driver, void *data);
 
 void ofono_radio_settings_register(struct ofono_radio_settings *rs);
 void ofono_radio_settings_remove(struct ofono_radio_settings *rs);
@@ -117,6 +133,9 @@ void ofono_radio_settings_remove(struct ofono_radio_settings *rs);
 void ofono_radio_settings_set_data(struct ofono_radio_settings *rs, void *data);
 void *ofono_radio_settings_get_data(struct ofono_radio_settings *rs);
 
+struct ofono_modem *ofono_radio_settings_get_modem(
+					struct ofono_radio_settings *rs);
+
 #ifdef __cplusplus
 }
 #endif
